summaryrefslogtreecommitdiffstats
path: root/kbabel/common/catalog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/common/catalog.h')
-rw-r--r--kbabel/common/catalog.h106
1 files changed, 53 insertions, 53 deletions
diff --git a/kbabel/common/catalog.h b/kbabel/common/catalog.h
index db47c48b..27b22bab 100644
--- a/kbabel/common/catalog.h
+++ b/kbabel/common/catalog.h
@@ -42,8 +42,8 @@
#include "catalogfileplugin.h"
#include "kbproject.h"
-#include <qptrlist.h>
-#include <qvaluevector.h>
+#include <tqptrlist.h>
+#include <tqvaluevector.h>
#include <kdemacros.h>
#include <kstandarddirs.h>
@@ -95,8 +95,8 @@ struct DocPosition
*/
struct DiffEntry
{
- QString msgid;
- QString msgstr;
+ TQString msgid;
+ TQString msgstr;
};
/**
@@ -121,17 +121,17 @@ public:
*
* @return Codec for found charset or 0, if no information has been found
*/
- static QTextCodec* codecForFile(QString gettextHeader);
+ static TQTextCodec* codecForFile(TQString gettextHeader);
static PoInfo headerInfo(const CatalogItem headerItem);
/**
* A constructor for an empty message catalog.
* @param parent parent @ref QObject for this catalog
* @param name unique name for this object
* @param configFile configuration file to read config from
*/
- Catalog(QObject* parent=0, const char* name=0, QString projectFile = QString() );
+ Catalog(TQObject* parent=0, const char* name=0, TQString projectFile = TQString() );
/**
* Deprecated. A copy constructor. Do not use since each Catalog registers
@@ -146,7 +146,7 @@ public:
* @param index index of the requested message
* @return context for the given message
*/
- QString msgctxt(uint index) const;
+ TQString msgctxt(uint index) const;
/**
* Get list of texts for a given message in original language. Each entry in the list
@@ -157,7 +157,7 @@ public:
* (useful for searching etc)
* @return list of singular/plural forms of the original text
*/
- QStringList msgid(uint index, const bool noNewlines=false) const;
+ TQStringList msgid(uint index, const bool noNewlines=false) const;
/**
* Get list of translated texts for a given message. Each entry in the list
@@ -168,7 +168,7 @@ public:
* (useful for searching etc)
* @return list of translated singular/plural forms
*/
- QStringList msgstr(uint index, const bool noNewlines=false) const;
+ TQStringList msgstr(uint index, const bool noNewlines=false) const;
/**
* Get the comment for a given message.
@@ -176,7 +176,7 @@ public:
* @param index index of the requested message
* @return comment for the given message
*/
- QString comment(uint index) const;
+ TQString comment(uint index) const;
/**
* Get the context information for a given message. This works
@@ -187,7 +187,7 @@ public:
* @return context information found in the message comment
* @deprecated
*/
- QString context(uint index) const KDE_DEPRECATED;
+ TQString context(uint index) const KDE_DEPRECATED;
/**
* Get the header for the current file.
@@ -201,31 +201,31 @@ public:
*
* @return string representation of the name and e-mail address
*/
- QString lastTranslator() const;
+ TQString lastTranslator() const;
/**
* @return The list of obsolete entries. These cannot be changed at
* all and are stored for import/export purposes.
*/
- QValueList<CatalogItem> obsoleteEntries() const;
+ TQValueList<CatalogItem> obsoleteEntries() const;
/**
* @return The index of the item, that has the msgid id.
* If no item is found, -1 is returned.
*/
- int indexForMsgid(const QString& id) const;
+ int indexForMsgid(const TQString& id) const;
/** @return a list of tags in entry #index */
- QStringList tagList(uint index);
+ TQStringList tagList(uint index);
/** @return a list of arguments in entry #index */
- QStringList argList(uint index);
+ TQStringList argList(uint index);
/**
* @return the list of errors found for a given item index
* @param index index of the item to check
*/
- QStringList itemStatus(uint index);
+ TQStringList itemStatus(uint index);
/**
* @return the list of errors found for a given item index
@@ -233,18 +233,18 @@ public:
* @param recheck flag, if the item status should be checked now
* @param whatToCheck what checks to do (a list of tools to be used
*/
- QStringList itemStatus(uint index, bool recheck, QPtrList<KDataTool> whatToCheck);
+ TQStringList itemStatus(uint index, bool recheck, TQPtrList<KDataTool> whatToCheck);
/**
* replaces msgstr in catalog item at index index with msgstr
* returns true, if untranslated status changed
*/
- //bool setMsgstr(uint index,QString msgstr);
+ //bool setMsgstr(uint index,TQString msgstr);
/**
* replaces comment in catalog item at index index with comment
* returns true, if fuzzy status changed
*/
- //bool setComment(uint index,QString comment);
+ //bool setComment(uint index,TQString comment);
/**
* replaces header with given String
* @return false if the header is not valid
@@ -270,40 +270,40 @@ public:
/**
* @return package name for the current catalog
*/
- QString packageName() const;
+ TQString packageName() const;
/**
* @return directory for the package of the current catalog
*/
- QString packageDir() const;
+ TQString packageDir() const;
/**
* @return package name and directory for the current catalog
*/
- QString package() const;
+ TQString package() const;
/**
* Setup the package for the catalog. It tries to parse the
* package and split it to name and directory
* @param package the name and directory to be set as package
*/
- void setPackage(const QString& package);
+ void setPackage(const TQString& package);
/**
* @return encoding for the current catalog
*/
- QString encoding() const;
+ TQString encoding() const;
/**
* opens file url by using KDE's network downlad and calls
* openFile with a local filename
*/
- ConversionStatus openURL(const KURL& url, const QString& package=QString::null);
+ ConversionStatus openURL(const KURL& url, const TQString& package=TQString::null);
/**
* opens file openURL by using KDE's network downlad and calls
* openFile with a local filename
* sets current URL to saveURL
*/
- ConversionStatus openURL(const KURL& openURL, const KURL& saveURL, const QString& package=QString::null);
+ ConversionStatus openURL(const KURL& openURL, const KURL& saveURL, const TQString& package=TQString::null);
/** save the file under the old filename */
ConversionStatus saveFile();
@@ -314,25 +314,25 @@ public:
* saves the current catalog in a temporary file and
* returns the name and path of the file.
*/
- QString saveTempFile();
+ TQString saveTempFile();
/**
* @return extra data for the catalog as set by the import filter
*/
- QStringList catalogExtraData() const;
+ TQStringList catalogExtraData() const;
/**
* @return ID string of the used import filter
*/
- QString importPluginID() const;
+ TQString importPluginID() const;
/**
* @return list of MIME types (separated by comma) this catalog
* can be viewed as. It is set by the used import filter.
*/
- QString mimeTypes() const;
+ TQString mimeTypes() const;
/**
* @return the file codec used for the current catalog
*/
- QTextCodec* fileCodec() const;
+ TQTextCodec* fileCodec() const;
/**
* Check syntax of the GNU gettext PO file using 'msgfmt'.
@@ -341,7 +341,7 @@ public:
* @param clearError should the errors be cleared before running msgfmt
* @return the file codec used for the current catalog
*/
- Msgfmt::Status checkSyntax(QString& output, bool clearErrors=true);
+ Msgfmt::Status checkSyntax(TQString& output, bool clearErrors=true);
/**
* checks using an external tool. The tool must provide the "validate" command
@@ -355,7 +355,7 @@ public:
* with the datatype expected to be CatalogItem *. The MIME type
* is application/x-kbabel-catalogitem.
*/
- void modifyUsingTool(KDataTool* tool, const QString& command);
+ void modifyUsingTool(KDataTool* tool, const TQString& command);
/**
* Returns true, if there is an ongoing activity, such as load/save
@@ -483,7 +483,7 @@ public:
* the search in po-files. This way, I can easily find the first
* catalog entry in the textstream
*/
-// static ConversionStatus readHeader(QTextStream& stream,CatalogItem& header);
+// static ConversionStatus readHeader(TQTextStream& stream,CatalogItem& header);
void registerView(CatalogView* view);
@@ -531,23 +531,23 @@ public:
* tries to find a corresponding entry for entry entry
* from the list of old messages and calculates the diff for it
*/
- DiffResult diff(uint entry, QString* result);
+ DiffResult diff(uint entry, TQString* result);
/**
* sets a list of entries to generate a diff from
*/
- void setDiffList( const QValueList<DiffEntry>& );
+ void setDiffList( const TQValueList<DiffEntry>& );
/**
* @return the contents of this catalog as list for diffs
*/
- QValueList<DiffEntry> asDiffList();
+ TQValueList<DiffEntry> asDiffList();
/**
* @return how many plural forms are used in language lang.
* If nothing is found -1 is returned.
*/
- static int getNumberOfPluralForms(const QString& lang);
+ static int getNumberOfPluralForms(const TQString& lang);
public slots:
/**
@@ -611,7 +611,7 @@ private:
void processCommand(EditCommand* cmd, CatalogView* view2exclude=0, bool undo=false);
/** do the actual file write using plugin */
- ConversionStatus writeFile(QString localfile, bool overwrite=false);
+ ConversionStatus writeFile(TQString localfile, bool overwrite=false);
/**
* generates lists that contain indexes of all fuzzy and untranslated entries
@@ -622,15 +622,15 @@ private:
* returns value in list that is lower than parameter index
* or -1 if there is none
*/
- int findPrevInList(const QValueList<uint>& list,uint index) const;
+ int findPrevInList(const TQValueList<uint>& list,uint index) const;
/**
* returns value in list that is bigger than parameter index
* or -1 if there is none
*/
- int findNextInList(const QValueList<uint>& list,uint index) const;
+ int findNextInList(const TQValueList<uint>& list,uint index) const;
/** returns the current date and time in the format of the users choice */
- QString dateTime() const;
+ TQString dateTime() const;
/** clear the list of all errors */
void clearErrorList();
@@ -648,26 +648,26 @@ private:
/** set the flag that the catalog is generated from docbook */
void setGeneratedFromDocbook(const bool generated);
/** set the entries of the catalog */
- void setEntries( QValueVector<CatalogItem> entries);
+ void setEntries( TQValueVector<CatalogItem> entries);
/** set the obsolete entries of the catalog */
- void setObsoleteEntries( QValueList<CatalogItem> entries);
+ void setObsoleteEntries( TQValueList<CatalogItem> entries);
/** set extra data for the catalog as defined by import plugin */
- void setCatalogExtraData(const QStringList& data);
+ void setCatalogExtraData(const TQStringList& data);
/** set file codec for the catalog */
- void setFileCodec(QTextCodec* codec);
+ void setFileCodec(TQTextCodec* codec);
/** set the list of import errors */
- void setErrorIndex(const QValueList<uint>&errors);
+ void setErrorIndex(const TQValueList<uint>&errors);
/** set ID of the used import plugin */
- void setImportPluginID(const QString& id);
+ void setImportPluginID(const TQString& id);
/** set the MIME types for the current catalog as defined by import plugin */
- void setMimeTypes(const QString& mimeTypes);
+ void setMimeTypes(const TQString& mimeTypes);
private:
CatalogPrivate* d;
signals:
- void signalError(QString);
- void signalResetProgressBar(QString,int);
+ void signalError(TQString);
+ void signalResetProgressBar(TQString,int);
void signalProgress(int);
void signalClearProgressBar();
@@ -121,17 +121,17 @@ public:
/**
* A constructor for an empty message catalog.
- * @param parent parent @ref QObject for this catalog
+ * @param parent parent @ref TQObject for this catalog
* @param name unique name for this object
* @param configFile configuration file to read config from